import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class AccountService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all admins
     * Get all admins for a smart account.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getAllAdmins(chain: string, contractAddress: string): CancelablePromise<{
        /**
         * The address of the admins on this account
         */
        result: Array<string>;
    }>;
    /**
     * Get all session keys
     * Get all session keys for a smart account.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getAllSessions(chain: string, contractAddress: string): CancelablePromise<{
        result: Array<{
            signerAddress: string;
            startDate: string;
            expirationDate: string;
            nativeTokenLimitPerTransaction: string;
            approvedCallTargets: Array<string>;
        }>;
    }>;
    /**
     * Grant admin
     * Grant a smart account's admin permission.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    grantAdmin(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to grant admin permissions to
         */
        signerAddress: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke admin
     * Revoke a smart account's admin permission.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    revokeAdmin(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to revoke admin permissions from
         */
        walletAddress: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Create session key
     * Create a session key for a smart account.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    grantSession(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        signerAddress: string;
        startDate: string;
        expirationDate: string;
        nativeTokenLimitPerTransaction: string;
        approvedCallTargets: Array<string>;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke session key
     * Revoke a session key for a smart account.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    revokeSession(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to revoke session from
         */
        walletAddress: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Update session key
     * Update a session key for a smart account.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    updateSession(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        signerAddress: string;
        approvedCallTargets: Array<string>;
        startDate?: string;
        expirationDate?: string;
        nativeTokenLimitPerTransaction?: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
