import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class BackendWalletService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create backend wallet
     * Create a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody?: {
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Import backend wallet
     * Import an existing wallet as a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    import(requestBody?: ({
        /**
         * AWS KMS Key ID
         */
        awsKmsKeyId: string;
        /**
         * AWS KMS Key ARN
         */
        awsKmsArn: string;
    } | {
        /**
         * GCP KMS Key ID
         */
        gcpKmsKeyId: string;
        /**
         * GCP KMS Key Version ID
         */
        gcpKmsKeyVersionId: string;
    } | ({
        /**
         * The private key of the wallet to import
         */
        privateKey: string;
    } | {
        /**
         * The mnemonic phrase of the wallet to import
         */
        mnemonic: string;
    } | {
        /**
         * The encrypted JSON of the wallet to import
         */
        encryptedJson: string;
        /**
         * The password used to encrypt the encrypted JSON
         */
        password: string;
    }))): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Get balance
     * Get the native balance for a backend wallet.
     * @param chain Chain ID name
     * @param walletAddress Wallet Address
     * @returns any Default Response
     * @throws ApiError
     */
    getBalance(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            walletAddress: string;
            name: string;
            symbol: string;
            decimals: number;
            value: string;
            displayValue: string;
        };
    }>;
    /**
     * Get all backend wallets
     * Get all backend wallets.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(): CancelablePromise<{
        result: Array<{
            /**
             * Wallet Address
             */
            address: string;
            /**
             * Wallet Type
             */
            type: string;
            label: (string | null);
            awsKmsKeyId: (string | null);
            awsKmsArn: (string | null);
            gcpKmsKeyId: (string | null);
            gcpKmsKeyRingId: (string | null);
            gcpKmsLocationId: (string | null);
            gcpKmsKeyVersionId: (string | null);
            gcpKmsResourcePath: (string | null);
        }>;
    }>;
    /**
     * Transfer tokens
     * Transfer native or ERC20 tokens from this wallet to another wallet
     * @param chain Chain ID name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to transfer to
         */
        to: string;
        /**
         * Address of the token to transfer
         */
        currencyAddress: string;
        /**
         * The amount of tokens to transfer
         */
        amount: string;
    }): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a raw transaction
     * Send a raw transaction with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        toAddress?: string;
        data: string;
        value: string;
    }): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
