import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class Erc1155Service {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get details
     * Get the details for a token in an ERC-1155 contract.
     * @param tokenId The tokenId of the NFT to retrieve
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    get(tokenId: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            metadata: Record<string, any>;
            owner: string;
            type: ('ERC1155' | 'ERC721' | 'metaplex');
            supply: string;
            quantityOwned?: string;
        };
    }>;
    /**
     * Get all details
     * Get details for all tokens in an ERC-1155 contract.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param start The start token id for paginated results. Defaults to 0.
     * @param count The page count for paginated results. Defaults to 100.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(chain: string, contractAddress: string, start?: number, count?: number): CancelablePromise<{
        result: Array<{
            metadata: Record<string, any>;
            owner: string;
            type: ('ERC1155' | 'ERC721' | 'metaplex');
            supply: string;
            quantityOwned?: string;
        }>;
    }>;
    /**
     * Get owned tokens
     * Get all tokens in an ERC-1155 contract owned by a specific wallet.
     * @param walletAddress Address of the wallet to get NFTs for
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    getOwned(walletAddress: string, chain: string, contractAddress: string): CancelablePromise<{
        result: Array<{
            metadata: Record<string, any>;
            owner: string;
            type: ('ERC1155' | 'ERC721' | 'metaplex');
            supply: string;
            quantityOwned?: string;
        }>;
    }>;
    /**
     * Get balance
     * Get the balance of a specific wallet address for this ERC-1155 contract.
     * @param walletAddress Address of the wallet to check NFT balance
     * @param tokenId The tokenId of the NFT to check balance of
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    balanceOf(walletAddress: string, tokenId: string, chain: string, contractAddress: string): CancelablePromise<{
        result?: string;
    }>;
    /**
     * Check if approved transfers
     * Check if the specific wallet has approved transfers from a specific operator wallet.
     * @param ownerWallet Address of the wallet who owns the NFT
     * @param operator Address of the operator to check approval on
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    isApproved(ownerWallet: string, operator: string, chain: string, contractAddress: string): CancelablePromise<{
        result?: boolean;
    }>;
    /**
     * Get total supply
     * Get the total supply in circulation for this ERC-1155 contract.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    totalCount(chain: string, contractAddress: string): CancelablePromise<{
        result?: string;
    }>;
    /**
     * Get total supply
     * Get the total supply in circulation for this ERC-1155 contract.
     * @param tokenId The tokenId of the NFT to retrieve
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    totalSupply(tokenId: string, chain: string, contractAddress: string): CancelablePromise<{
        result?: string;
    }>;
    /**
     * Generate signature
     * Generate a signature granting access for another wallet to mint tokens from this ERC-721 contract. This method is typically called by the token contract owner.
     * @param chain Chain ID or name
     * @param contractAddress ERC721 Contract Address on the Chain
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    signatureGenerate(chain: string, contractAddress: string, requestBody: {
        /**
         * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
         */
        to: string;
        /**
         * The number of tokens this signature can be used to mint.
         */
        quantity: string;
        metadata: ({
            name?: (string | number | null);
            description?: (string | null);
            image?: (string | null);
            external_url?: (string | null);
            animation_url?: (string | null);
            properties?: null;
            attributes?: null;
            background_color?: null;
        } | string);
        /**
         * The address that will receive the royalty fees from secondary sales. Defaults to the royaltyRecipient address of the contract.
         */
        royaltyRecipient?: string;
        /**
         * The percentage fee you want to charge for secondary sales. Defaults to the royaltyBps of the contract.
         */
        royaltyBps?: number;
        /**
         * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
         */
        primarySaleRecipient?: string;
        /**
         * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
         * Note that the input value gets hashed in the actual payload that gets generated.
         * The smart contract enforces on-chain that no uid gets used more than once,
         * which means you can deterministically generate the uid to prevent specific exploits.
         */
        uid?: string;
        /**
         * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
         */
        currencyAddress?: string;
        /**
         * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
         */
        price?: string;
        mintStartTime?: (string | number);
        mintEndTime?: (string | number);
    }): CancelablePromise<{
        result: {
            payload: {
                uri: string;
                tokenId: string;
                /**
                 * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
                 */
                to: string;
                /**
                 * The address that will receive the royalty fees from secondary sales. Defaults to the royaltyRecipient address of the contract.
                 */
                royaltyRecipient: string;
                /**
                 * The number of tokens this signature can be used to mint.
                 */
                quantity: string;
                /**
                 * The percentage fee you want to charge for secondary sales. Defaults to the royaltyBps of the contract.
                 */
                royaltyBps: string;
                /**
                 * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
                 */
                primarySaleRecipient: string;
                /**
                 * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
                 * Note that the input value gets hashed in the actual payload that gets generated.
                 * The smart contract enforces on-chain that no uid gets used more than once,
                 * which means you can deterministically generate the uid to prevent specific exploits.
                 */
                uid: string;
                metadata: ({
                    name?: (string | number | null);
                    description?: (string | null);
                    image?: (string | null);
                    external_url?: (string | null);
                    animation_url?: (string | null);
                    properties?: null;
                    attributes?: null;
                    background_color?: null;
                } | string);
                /**
                 * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
                 */
                currencyAddress: string;
                /**
                 * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
                 */
                price: string;
                /**
                 * The time from which the signature can be used to mint tokens. Defaults to now if value not provided.
                 */
                mintStartTime: number;
                /**
                 * The time until which the signature can be used to mint tokens. Defaults to 10 years from now.
                 */
                mintEndTime: number;
            };
            signature: string;
        };
    }>;
    /**
     * Airdrop tokens
     * Airdrop ERC-1155 tokens to specific wallets.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    airdrop(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Token ID of the NFT to airdrop
         */
        tokenId: string;
        /**
         * Addresses and quantities to airdrop to
         */
        addresses: Array<{
            address: string;
            quantity: string;
        }>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Burn token
     * Burn ERC-1155 tokens in the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    burn(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The token ID to burn
         */
        tokenId: string;
        /**
         * The amount of tokens to burn
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Burn tokens (batch)
     * Burn a batch of ERC-1155 tokens in the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    burnBatch(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        tokenIds: Array<string>;
        amounts: Array<string>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Claim tokens to wallet
     * Claim ERC-1155 tokens to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    claimTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to claim the NFT to
         */
        receiver: string;
        /**
         * Token ID of the NFT to claim
         */
        tokenId: string;
        /**
         * Quantity of NFTs to mint
         */
        quantity: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Lazy mint
     * Lazy mint ERC-1155 tokens to be claimed in the future.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    lazyMint(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        metadatas: Array<({
            name?: (string | number | null);
            description?: (string | null);
            image?: (string | null);
            external_url?: (string | null);
            animation_url?: (string | null);
            properties?: null;
            attributes?: null;
            background_color?: null;
        } | string)>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Mint additional supply
     * Mint additional supply of ERC-1155 tokens to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    mintAdditionalSupplyTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to mint the NFT to
         */
        receiver: string;
        /**
         * Token ID to mint additional supply to
         */
        tokenId: string;
        /**
         * The amount of supply to mint
         */
        additionalSupply: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Mint tokens (batch)
     * Mint ERC-1155 tokens to multiple wallets in one transaction.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    mintBatchTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to mint the NFT to
         */
        receiver: string;
        metadataWithSupply: Array<{
            metadata: ({
                name?: (string | number | null);
                description?: (string | null);
                image?: (string | null);
                external_url?: (string | null);
                animation_url?: (string | null);
                properties?: null;
                attributes?: null;
                background_color?: null;
            } | string);
            supply: string;
        }>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Mint tokens
     * Mint ERC-1155 tokens to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    mintTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to mint the NFT to
         */
        receiver: string;
        metadataWithSupply: {
            metadata: ({
                name?: (string | number | null);
                description?: (string | null);
                image?: (string | null);
                external_url?: (string | null);
                animation_url?: (string | null);
                properties?: null;
                attributes?: null;
                background_color?: null;
            } | string);
            supply: string;
        };
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Set approval for all
     * Approve or remove operator as an operator for the caller. Operators can call transferFrom or safeTransferFrom for any token owned by the caller.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    setApprovalForAll(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the operator to give approval to
         */
        operator: string;
        /**
         * whether to approve or revoke approval
         */
        approved: boolean;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Transfer token
     * Transfer an ERC-1155 token from the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to transfer to
         */
        to: string;
        /**
         * the tokenId to transfer
         */
        tokenId: string;
        /**
         * the amount of tokens to transfer
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Transfer token from wallet
     * Transfer an ERC-1155 token from the connected wallet to another wallet. Requires allowance.
     * @param chain Chain ID or name
     * @param contractAddress ERC1155 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    transferFrom(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the token owner
         */
        from: string;
        /**
         * Address of the wallet to transferFrom to
         */
        to: string;
        /**
         * the tokenId to transferFrom
         */
        tokenId: string;
        /**
         * the amount of tokens to transfer
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Signature mint
     * Mint ERC-1155 tokens from a generated signature.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    signatureMint(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        payload: {
            uri: string;
            tokenId: string;
            /**
             * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
             */
            to: string;
            /**
             * The address that will receive the royalty fees from secondary sales. Defaults to the royaltyRecipient address of the contract.
             */
            royaltyRecipient: string;
            /**
             * The number of tokens this signature can be used to mint.
             */
            quantity: string;
            /**
             * The percentage fee you want to charge for secondary sales. Defaults to the royaltyBps of the contract.
             */
            royaltyBps: string;
            /**
             * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
             */
            primarySaleRecipient: string;
            /**
             * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
             * Note that the input value gets hashed in the actual payload that gets generated.
             * The smart contract enforces on-chain that no uid gets used more than once,
             * which means you can deterministically generate the uid to prevent specific exploits.
             */
            uid: string;
            metadata: ({
                name?: (string | number | null);
                description?: (string | null);
                image?: (string | null);
                external_url?: (string | null);
                animation_url?: (string | null);
                properties?: null;
                attributes?: null;
                background_color?: null;
            } | string);
            /**
             * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
             */
            currencyAddress: string;
            /**
             * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
             */
            price: string;
            /**
             * The time from which the signature can be used to mint tokens. Defaults to now if value not provided.
             */
            mintStartTime: number;
            /**
             * The time until which the signature can be used to mint tokens. Defaults to 10 years from now.
             */
            mintEndTime: number;
        };
        signature: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
