import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class Erc20Service {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get token allowance
     * Get the allowance of a specific wallet for an ERC-20 contract.
     * @param ownerWallet Address of the wallet who owns the funds
     * @param spenderWallet Address of the wallet to check token allowance
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    allowanceOf(ownerWallet: string, spenderWallet: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            name: string;
            symbol: string;
            decimals: string;
            /**
             * Value in wei
             */
            value: string;
            /**
             * Value in tokens
             */
            displayValue: string;
        };
    }>;
    /**
     * Get token balance
     * Get the balance of a specific wallet address for this ERC-20 contract.
     * @param walletAddress Address of the wallet to check token balance
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    balanceOf(walletAddress: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            name: string;
            symbol: string;
            decimals: string;
            /**
             * Value in wei
             */
            value: string;
            /**
             * Value in tokens
             */
            displayValue: string;
        };
    }>;
    /**
     * Get token details
     * Get details for this ERC-20 contract.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    get(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            name: string;
            symbol: string;
            decimals: string;
        };
    }>;
    /**
     * Get total supply
     * Get the total supply in circulation for this ERC-20 contract.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    totalSupply(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            name: string;
            symbol: string;
            decimals: string;
            /**
             * Value in wei
             */
            value: string;
            /**
             * Value in tokens
             */
            displayValue: string;
        };
    }>;
    /**
     * Generate signature
     * Generate a signature granting access for another wallet to mint tokens from this ERC-20 contract. This method is typically called by the token contract owner.
     * @param chain Chain ID or name
     * @param contractAddress ERC721 Contract Address on the Chain
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    signatureGenerate(chain: string, contractAddress: string, requestBody: {
        /**
         * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
         */
        to: string;
        /**
         * The number of tokens this signature can be used to mint.
         */
        quantity: string;
        /**
         * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
         */
        primarySaleRecipient?: string;
        /**
         * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
         * Note that the input value gets hashed in the actual payload that gets generated.
         * The smart contract enforces on-chain that no uid gets used more than once,
         * which means you can deterministically generate the uid to prevent specific exploits.
         */
        uid?: string;
        /**
         * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
         */
        currencyAddress?: string;
        /**
         * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
         */
        price?: string;
        mintStartTime?: (string | number);
        mintEndTime?: (string | number);
    }): CancelablePromise<{
        result: {
            payload: {
                /**
                 * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
                 */
                to: string;
                /**
                 * The number of tokens this signature can be used to mint.
                 */
                quantity: string;
                /**
                 * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
                 */
                primarySaleRecipient: string;
                /**
                 * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
                 * Note that the input value gets hashed in the actual payload that gets generated.
                 * The smart contract enforces on-chain that no uid gets used more than once,
                 * which means you can deterministically generate the uid to prevent specific exploits.
                 */
                uid: string;
                /**
                 * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
                 */
                currencyAddress: string;
                /**
                 * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
                 */
                price: string;
                /**
                 * The time from which the signature can be used to mint tokens. Defaults to now.
                 */
                mintStartTime: number;
                /**
                 * The time until which the signature can be used to mint tokens. Defaults to 10 years from now.
                 */
                mintEndTime: number;
            };
            signature: string;
        };
    }>;
    /**
     * Set allowance
     * Grant a specific wallet address to transfer ERC-20 tokens from the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    setAllowance(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to allow transfers from
         */
        spenderAddress: string;
        /**
         * The number of tokens to give as allowance
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Transfer tokens
     * Transfer ERC-20 tokens from the caller wallet to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet you want to send the tokens to
         */
        toAddress: string;
        /**
         * The amount of tokens you want to send
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Transfer tokens from wallet
     * Transfer ERC-20 tokens from the connected wallet to another wallet. Requires allowance.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    transferFrom(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet sending the tokens
         */
        fromAddress: string;
        /**
         * Address of the wallet you want to send the tokens to
         */
        toAddress: string;
        /**
         * The amount of tokens you want to send
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Burn token
     * Burn ERC-20 tokens in the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    burn(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The amount of tokens you want to burn
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Burn token from wallet
     * Burn ERC-20 tokens in a specific wallet. Requires allowance.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    burnFrom(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet sending the tokens
         */
        holderAddress: string;
        /**
         * The amount of this token you want to burn
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Claim tokens to wallet
     * Claim ERC-20 tokens to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    claimTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The wallet address to receive the claimed tokens.
         */
        recipient: string;
        /**
         * The amount of tokens to claim.
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Mint tokens (batch)
     * Mint ERC-20 tokens to multiple wallets in one transaction.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    mintBatchTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        data: Array<{
            /**
             * The address to mint tokens to
             */
            toAddress: string;
            /**
             * The number of tokens to mint to the specific address.
             */
            amount: string;
        }>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Mint tokens
     * Mint ERC-20 tokens to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress ERC20 Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    mintTo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to mint tokens to
         */
        toAddress: string;
        /**
         * The amount of tokens you want to send
         */
        amount: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Signature mint
     * Mint ERC-20 tokens from a generated signature.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    signatureMint(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        payload: {
            /**
             * The wallet address that can use this signature to mint tokens. This is to prevent another wallet from intercepting the signature and using it to mint tokens for themselves.
             */
            to: string;
            /**
             * The number of tokens this signature can be used to mint.
             */
            quantity: string;
            /**
             * If a price is specified, the funds will be sent to the primarySaleRecipient address. Defaults to the primarySaleRecipient address of the contract.
             */
            primarySaleRecipient: string;
            /**
             * A unique identifier for the payload, used to prevent replay attacks and other types of exploits.
             * Note that the input value gets hashed in the actual payload that gets generated.
             * The smart contract enforces on-chain that no uid gets used more than once,
             * which means you can deterministically generate the uid to prevent specific exploits.
             */
            uid: string;
            /**
             * The address of the currency to pay for minting the tokens (use the price field to specify the price). Defaults to NATIVE_TOKEN_ADDRESS
             */
            currencyAddress: string;
            /**
             * If you want the user to pay for minting the tokens, you can specify the price per token. Defaults to 0.
             */
            price: string;
            /**
             * The time from which the signature can be used to mint tokens. Defaults to now.
             */
            mintStartTime: number;
            /**
             * The time until which the signature can be used to mint tokens. Defaults to 10 years from now.
             */
            mintEndTime: number;
        };
        signature: string;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
