import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class MarketplaceDirectListingsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all listings
     * Get all direct listings for this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param count Number of listings to fetch
     * @param seller Being sold by this Address
     * @param start Satrt from this index (pagination)
     * @param tokenContract Token contract address to show NFTs from
     * @param tokenId Only show NFTs with this ID
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(chain: string, contractAddress: string, count?: number, seller?: string, start?: number, tokenContract?: string, tokenId?: string): CancelablePromise<{
        result: Array<{
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The price to pay per unit of NFTs listed.
             */
            pricePerToken: string;
            /**
             * Whether the listing is reserved to be bought from a specific set of buyers.
             */
            isReservedListing?: boolean;
            /**
             * The id of the listing.
             */
            id: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValuePerToken?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            asset?: Record<string, any>;
            status?: (number | 1 | 2 | 3 | 4 | 5);
            /**
             * The start time of the listing. If not set, defaults to now.
             */
            startTimeInSeconds?: number;
            /**
             * The end time of the listing. If not set, defaults to 7 days from now.
             */
            endTimeInSeconds?: number;
        }>;
    }>;
    /**
     * Get all valid listings
     * Get all the valid direct listings for this marketplace contract. A valid listing is where the listing is active, and the creator still owns & has approved Marketplace to transfer the listed NFTs.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param count Number of listings to fetch
     * @param seller Being sold by this Address
     * @param start Satrt from this index (pagination)
     * @param tokenContract Token contract address to show NFTs from
     * @param tokenId Only show NFTs with this ID
     * @returns any Default Response
     * @throws ApiError
     */
    getAllValid(chain: string, contractAddress: string, count?: number, seller?: string, start?: number, tokenContract?: string, tokenId?: string): CancelablePromise<{
        result: Array<{
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The price to pay per unit of NFTs listed.
             */
            pricePerToken: string;
            /**
             * Whether the listing is reserved to be bought from a specific set of buyers.
             */
            isReservedListing?: boolean;
            /**
             * The id of the listing.
             */
            id: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValuePerToken?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            asset?: Record<string, any>;
            status?: (number | 1 | 2 | 3 | 4 | 5);
            /**
             * The start time of the listing. If not set, defaults to now.
             */
            startTimeInSeconds?: number;
            /**
             * The end time of the listing. If not set, defaults to 7 days from now.
             */
            endTimeInSeconds?: number;
        }>;
    }>;
    /**
     * Get direct listing
     * Gets a direct listing on this marketplace contract.
     * @param listingId The id of the listing to retrieve.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    getListing(listingId: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The price to pay per unit of NFTs listed.
             */
            pricePerToken: string;
            /**
             * Whether the listing is reserved to be bought from a specific set of buyers.
             */
            isReservedListing?: boolean;
            /**
             * The id of the listing.
             */
            id: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValuePerToken?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            asset?: Record<string, any>;
            status?: (number | 1 | 2 | 3 | 4 | 5);
            /**
             * The start time of the listing. If not set, defaults to now.
             */
            startTimeInSeconds?: number;
            /**
             * The end time of the listing. If not set, defaults to 7 days from now.
             */
            endTimeInSeconds?: number;
        };
    }>;
    /**
     * Check approved buyer
     * Check if a buyer is approved to purchase a specific direct listing.
     * @param listingId The id of the listing to retrieve.
     * @param walletAddress The wallet address of the buyer to check.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    isBuyerApprovedForListing(listingId: string, walletAddress: string, chain: string, contractAddress: string, xBackendWalletAddress: string, xAccountAddress?: string): CancelablePromise<{
        result: boolean;
    }>;
    /**
     * Check approved currency
     * Check if a currency is approved for a specific direct listing.
     * @param listingId The id of the listing to retrieve.
     * @param currencyContractAddress The smart contract address of the ERC20 token to check.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    isCurrencyApprovedForListing(listingId: string, currencyContractAddress: string, chain: string, contractAddress: string): CancelablePromise<{
        result: boolean;
    }>;
    /**
     * Transfer token from wallet
     * Get the total number of direct listings on this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    getTotalCount(chain: string, contractAddress: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Create direct listing
     * Create a direct listing on this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    createListing(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The address of the asset being listed.
         */
        assetContractAddress: string;
        /**
         * The ID of the token to list.
         */
        tokenId: string;
        /**
         * The address of the currency to accept for the listing.
         */
        currencyContractAddress?: string;
        /**
         * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
         */
        quantity?: string;
        /**
         * The price to pay per unit of NFTs listed.
         */
        pricePerToken: string;
        /**
         * Whether the listing is reserved to be bought from a specific set of buyers.
         */
        isReservedListing?: boolean;
        /**
         * The start time of the listing. If not set, defaults to now.
         */
        startTimestamp?: number;
        /**
         * The end time of the listing. If not set, defaults to 7 days from now.
         */
        endTimestamp?: number;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Update direct listing
     * Update a direct listing on this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param xAccountAddress Smart account address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateListing(chain: string, contractAddress: string, xBackendWalletAddress: string, xAccountAddress?: string, requestBody?: ({
        /**
         * The ID of the listing you want to update.
         */
        listingId: string;
    } & {
        /**
         * The address of the asset being listed.
         */
        assetContractAddress: string;
        /**
         * The ID of the token to list.
         */
        tokenId: string;
        /**
         * The address of the currency to accept for the listing.
         */
        currencyContractAddress?: string;
        /**
         * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
         */
        quantity?: string;
        /**
         * The price to pay per unit of NFTs listed.
         */
        pricePerToken: string;
        /**
         * Whether the listing is reserved to be bought from a specific set of buyers.
         */
        isReservedListing?: boolean;
        /**
         * The start time of the listing. If not set, defaults to now.
         */
        startTimestamp?: number;
        /**
         * The end time of the listing. If not set, defaults to 7 days from now.
         */
        endTimestamp?: number;
    })): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Buy from direct listing
     * Buy from a specific direct listing from this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    buyFromListing(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the listing you want to approve a buyer for.
         */
        listingId: string;
        /**
         * The number of tokens to buy (default is 1 for ERC721 NFTs).
         */
        quantity: string;
        /**
         * The wallet address of the buyer.
         */
        buyer: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Approve buyer for reserved listing
     * Approve a wallet address to buy from a reserved listing.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    approveBuyerForReservedListing(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the listing you want to approve a buyer for.
         */
        listingId: string;
        /**
         * The wallet address of the buyer to approve.
         */
        buyer: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke approval for reserved listings
     * Revoke approval for a buyer to purchase a reserved listing.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    revokeBuyerApprovalForReservedListing(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the listing you want to approve a buyer for.
         */
        listingId: string;
        /**
         * The wallet address of the buyer to approve.
         */
        buyerAddress: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke currency approval for reserved listing
     * Revoke approval of a currency for a reserved listing.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    revokeCurrencyApprovalForListing(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the listing you want to approve a buyer for.
         */
        listingId: string;
        /**
         * The wallet address of the buyer to approve.
         */
        currencyContractAddress: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
